@@ -29,10 +29,12 @@ SharedHandle::SharedHandle(DataHandle& handle) :
 SharedHandle::~SharedHandle() {}
 
 void SharedHandle::print(std::ostream& s) const {
-    if (format(s) == Log::compactFormat)
+    if (format(s) == Log::compactFormat) {
         s << "SharedHandle";
-    else
+    }
+    else {
         s << "SharedHandle[handle=" << handle_ << ']';
+    }
 }
 
 Length SharedHandle::openForRead() {
@@ -140,7 +142,7 @@ void SharedHandle::toRemote(Stream& s) const {
     NOTIMP;
 }
 
-void SharedHandle::cost(std::map<std::string, Length>&, bool) const {
+void SharedHandle::selectMover(MoverTransferSelection&, bool) const {
     NOTIMP;
 }
 
