@@ -21,9 +21,7 @@ using namespace std;
 using namespace eckit;
 using namespace eckit::testing;
 
-
-namespace eckit {
-namespace test {
+namespace eckit::test {
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -124,15 +122,21 @@ CASE("copy and move assign") {
         EXPECT(!opt3);
 
         // Self move-assignement
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wself-move"
         opt2 = std::move(opt2);
+#pragma clang diagnostic pop
         EXPECT(opt2);
         EXPECT(opt2.value() == 2);
-        
+
         // Self copy-assignement
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wself-assign-overloaded"
         opt2 = opt2;
+#pragma clang diagnostic pop
         EXPECT(opt2);
         EXPECT(opt2.value() == 2);
-        
+
         // Assign none
         opt2 = nullopt;
         EXPECT(!opt2);
@@ -194,7 +198,10 @@ CASE("non-trivial object: std::string") {
 
         // Test move assign to self
         Optional<std::string> optTmp4("tmp4");
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wself-move"
         optTmp4 = std::move(optTmp4);
+#pragma clang diagnostic pop
         EXPECT(optTmp4);
         EXPECT_EQUAL(optTmp4.value(), std::string("tmp4"));
 
@@ -302,7 +309,7 @@ CASE("test destructor on non-trivial object: copy assign value") {
         EXPECT_EQUAL(opt.value().str, std::string("testCopyAssignValue1"));
         int testCopyAssignValue1OptId  = opt.value().id;
         int testCopyAssignValue1OptUId = opt.value().uid;
-        
+
         // Test copy assign value Some <- Some
         StringWrap testCopyAssignValue2("testCopyAssignValue2");
         int testCopyAssignValue2Id  = testCopyAssignValue2.id;
@@ -329,7 +336,7 @@ CASE("test destructor on non-trivial object: copy assign value") {
     }
 }
 
-        
+
 CASE("test destructor on non-trivial object: move assign value") {
     {
         Optional<StringWrap> opt;
@@ -361,15 +368,15 @@ CASE("test destructor on non-trivial object: move assign value") {
         EXPECT(!StringWrap::idIsDeleted(testMoveAssignValue1OptId));
         EXPECT(!StringWrap::uidIsDeleted(testMoveAssignValue1OptUId));
         EXPECT(!StringWrap::uidIsDeleted(testMoveAssignValue2UId));
-        
-        
+
+
         Optional<StringWrap> testCopyAssignSomeNone;
         opt = testCopyAssignSomeNone;
         EXPECT(!opt);
         // Reset should delete previous object
         EXPECT(StringWrap::idIsDeleted(testMoveAssignValue2OptId));
         EXPECT(StringWrap::uidIsDeleted(testMoveAssignValue2OptUId));
-   }
+    }
 }
 
 CASE("test destructor on non-trivial object: copy & move assign optional") {
@@ -408,7 +415,7 @@ CASE("test destructor on non-trivial object: copy & move assign optional") {
         EXPECT(!StringWrap::uidIsDeleted(testCopyAssignNoneSomeOptUId));
         EXPECT(!StringWrap::idIsDeleted(testCopyAssignSomeSomeId));
         EXPECT(!StringWrap::uidIsDeleted(testCopyAssignSomeSomeUId));
-        
+
         // Test move assign some <- some
         Optional<StringWrap> testMoveAssignSomeSome("testMoveAssignSomeSome");
         int testMoveAssignSomeSomeId  = testMoveAssignSomeSome.value().id;
@@ -546,8 +553,7 @@ CASE("constexpr") {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // end namespace test
-}  // end namespace eckit
+}  // namespace eckit::test
 
 int main(int argc, char* argv[]) {
     return run_tests(argc, argv);
